pub trait ContextLessSummary: Clone {
// Required methods
fn zero() -> Self;
fn add_summary(&mut self, summary: &Self);
}Required Methods
fn zero() -> Self
fn add_summary(&mut self, summary: &Self)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl ContextLessSummary for NoSummary
Catch-all implementation for when you need something that implements Summary without a specific type.
We implement it on a NoSummary instead of re-using (), as that avoids blanket impl collisions with impl<T: Summary> Dimension for T
(as we also need unit type to be a fill-in dimension)